@@ -18,4 +18,9 @@ class IntercomBaseModel(object):
     def get_list(self, *args, **kwargs):
         ret = requests.get("%s%s" % (self.base_request_url, self.name), auth=HTTPBasicAuth(self.app_id, self.app_api_key), headers={'content-type': 'application/json', 'accept': 'application/json'})
 
-        return ret.json()
\ No newline at end of file
+        return ret.json()
+
+    def create(self, request_dict={}):
+        ret = requests.post("%s%s" % (self.base_request_url, self.name), json.dumps(request_dict), auth=HTTPBasicAuth(self.app_id, self.app_api_key), headers={'content-type': 'application/json', 'accept': 'application/json'})
+
+        return ret.json()
